@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[64]:
+# In[66]:
 
 
 version = '0.29'
@@ -552,6 +552,48 @@ if is_testing():
     
 
 
+# In[ ]:
+
+
+import base64
+
+def jnImgToHtmlB64(img):
+    img = imread(img)
+    _, encimg = cv2.imencode('.png', img)
+    imgB64 = base64.b64encode(encimg).decode('utf-8')
+    img_tag = '<img src="data:image/png;base64,{0}" style="display:block; margin:0 auto;">'.format(imgB64)
+    return img_tag
+
+#def jnHtmlImgsRow(imgs, names=None):
+
+def jnImageTable(imgs, names=None, width=100):
+    _row = lambda x: '<tr>' + x + '</tr>'
+    _col = lambda x: '<td style="text-align:center">' + x + '</td>'
+    _cols = lambda x: "".join(map(_col, x))
+    _imcols = lambda x: "".join(map(_col, map(jnImgToHtmlB64, x)))
+    _tab = lambda x: '<table width="{width}%">'.format(width=width) + x + '</table>'
+    
+    header = "" if names is None else _row(_cols(names))
+    html = _tab(header + _row(_imcols(imgs)))
+    display(HTML(html))
+
+
+# In[123]:
+
+
+if is_testing():
+    jnImageTable(imgs=[imNewBlack(20, 20), imNewBlack(40, 20), imNewBlack(20, 800)], names=["a", "b", "c"])
+   
+
+
+# In[124]:
+
+
+
+if is_testing():
+   jnImageTable(imgs=[imNewBlack(20, 20), imNewBlack(40, 20), imNewBlack(20, 800)])
+
+
 # # Shell
 
 # In[54]:
@@ -579,7 +621,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[57]:
+# In[67]:
 
 
 if is_testing():
@@ -611,7 +653,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[58]:
+# In[68]:
 
 
 if is_testing():
@@ -621,7 +663,7 @@ description-file = README.md
 """
 
 
-# In[59]:
+# In[69]:
 
 
 if is_testing():
@@ -644,14 +686,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[60]:
+# In[70]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[61]:
+# In[71]:
 
 
 if is_testing():
@@ -665,7 +707,7 @@ if is_testing():
 
 
 
-# In[62]:
+# In[72]:
 
 
 if is_testing():
@@ -676,7 +718,7 @@ lx/__init__.py
 """
 
 
-# In[65]:
+# In[73]:
 
 
 if is_testing():
